@@ -45,8 +45,6 @@ CA <- function(data, typdata = "f", typmatrix = "I") {
     if (sum(data)!=round(sum(abs(data)),0))
        stop("The data should be positive integer numbers from counting. Verify!")
   
-  Nc = min(nrow(data) - 1, ncol(data) - 1) # numero de coordenadas principais
-  
   if (typdata == "C") {  
     # Converte para variaveis Dummy para execucao analise
     # de Correspondencia Multipla, ou seja, em 0 e 1, caso dados nominais
@@ -79,6 +77,8 @@ CA <- function(data, typdata = "f", typmatrix = "I") {
     
   } 
   
+  # Nc = min(nrow(data) - 1, ncol(data) - 1) # numero de coordenadas principais
+  
   SDados <- sum(data) # Soma Total dos Dados
   
   MP <- as.matrix(data/SDados) # Matriz P
@@ -140,12 +140,13 @@ CA <- function(data, typdata = "f", typmatrix = "I") {
   ##### FIM Calculo das Coordenadas principais das Linhas e Colunas #####
   
   ##### INICIO - Calculo das Inercia Total #####
-  MAutoVlr = diag(Md%*%Md)
+  MAutoVlr = Md[Md > 0.0001]^2
+  Nc <- length(MAutoVlr)
   MEigen <- as.data.frame(matrix(NA, Nc, 3))
   rownames(MEigen) <- paste("Comp", 1:Nc)
   colnames(MEigen) <- c("Eigenvalue", "Proporcion of the variance","Cumulative proportion of the variance")
-  MEigen[, "Eigenvalue"] <- MAutoVlr[1:Nc]
-  MEigen[, "Proporcion of the variance"] <- (MAutoVlr[1:Nc]/sum(MAutoVlr[1:Nc])) * 100
+  MEigen[, "Eigenvalue"] <- MAutoVlr
+  MEigen[, "Proporcion of the variance"] <- (MAutoVlr /sum(MAutoVlr )) * 100
   MEigen[, "Cumulative proportion of the variance"] <- cumsum(MEigen[,"Proporcion of the variance"])
   ##### FIM - Calculo das Inercia Total #####
   
